@@ -743,6 +743,7 @@ perform_nested_cv <- function(
       v = outside_folds,
       strata = all_of(strata)
     )
+    rm(distinct_ids)
 
     # Extract fold assignments from `assessment()` (test set)
     fold_assignments <- purrr::imap_dfr(stratified_folds$splits, ~ tibble::tibble(
@@ -750,6 +751,7 @@ perform_nested_cv <- function(
       fold = .y  # Assign fold index
     ))
 
+    rm(stratified_folds)
     # Ensure fold_assignments has unique IDs
     fold_assignments <- fold_assignments %>%
       dplyr::distinct(id_nr, .keep_all = TRUE)  # Keeps one row per unique `id_nr`
@@ -775,6 +777,7 @@ perform_nested_cv <- function(
         v = inside_folds
       )
     )
+    rm(fold_assignments)
   } else {
     # No stratification, just use standard `group_vfold_cv()`
     results_nested_resampling <- rsample::nested_cv(
@@ -791,7 +794,7 @@ perform_nested_cv <- function(
       )
     )
   }
-
+  rm(xy)
   return(results_nested_resampling)
 }
 
@@ -809,7 +812,10 @@ perform_nested_cv <- function(
 #' @return A plot if `strata` is provided, otherwise messages indicating checks.
 #' @importFrom purrr map2_dfr
 #' @noRd
-check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_nr", strata = NULL) {
+check_nested_cv_setup <- function(
+    results_nested_resampling,
+    id_variable = "id_nr",
+    strata = NULL) {
 
 
   # Extract fold assignments from `splits`, ensuring **each unique ID** is assigned once
@@ -862,12 +868,15 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
       "green"
     ))
   }
+  rm(missing_ids)
 
   # Check fold balance
   fold_distribution <- id_assignments %>%
     dplyr::count(fold) %>%
     dplyr::arrange(desc(n))
 
+  rm(id_assignments)
+
 
   message(colourise(
     "Fold balance checked.",
@@ -876,6 +885,7 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
   message(colourise(
     fold_distribution,
     "blue"))
+  rm(fold_distribution)
 
   # Check if stratification is preserved
   if (!is.null(strata)) {
@@ -903,26 +913,6 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
       dplyr::left_join(overall_distribution, by = as.character(strata)) %>%
       dplyr::mutate(abs_deviation = abs(fold_prop - overall_prop))
 
-    # Compute mean absolute error (MAE) for stratification balance
- #   mae_stratification <- mean(strata_check$abs_deviation, na.rm = TRUE)
-
-#    # Perform chi-square test for stratification consistency across folds
-#    strata_matrix <- tidyr::pivot_wider(
-#      strata_check,
-#      names_from = fold,
-#      values_from = n,
-#      values_fill = 0
-#    ) %>%
-#      dplyr::select(-!!rlang::sym(strata)) %>%
-#      as.matrix()
-#
-#    chi_sq_test <- chisq.test(strata_matrix)
-
-    # Print stratification summary
-#    print(strata_check)
-#    message(glue::glue("Stratification checked. Mean absolute deviation from overall distribution: {round(mae_stratification, 4)}"))
-#    message(glue::glue("Chi-square test p-value: {round(chi_sq_test$p.value, 4)}"))
-
     # Plot stratification distribution
     p <- ggplot2::ggplot(strata_check, ggplot2::aes(x = fold, y = fold_prop, fill = as.factor(!!rlang::sym(strata)))) +
       ggplot2::geom_bar(stat = "identity", position = "dodge") +
@@ -939,6 +929,10 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
       "green"
     ))
 
+    rm(results_nested_resampling)
+    rm(strata_check)
+    rm(overall_distribution)
+
     return(p)
   } else {
     message(colourise(
@@ -948,6 +942,75 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
   }
 }
 
+#' Create a manual nested cross-validation object using initial validation splits
+#'
+#' This function mimics `rsample::nested_cv()` but allows for the use of
+#' `initial_validation_split()` as the inner resampling method, which is not natively
+#' supported in `nested_cv()`. It performs stratified outer v-fold cross-validation,
+#' and within each outer fold it applies a training/validation split using
+#' `initial_validation_split()`, wrapped in `validation_set()` to ensure compatibility with tuning functions.
+#'
+#' @param data A data frame or tibble to be split.
+#' @param outside_folds Integer specifying the number of outer folds (default = 5).
+#' @param inside_prop A numeric scalar (e.g., 0.75) or a two-element vector (e.g., c(0.6, 0.2))
+#'        specifying the proportion of data to allocate to training and validation within each outer fold.
+#'        The sum must be < 1 (remaining is used for an optional test set).
+#' @param outside_strata Optional variable name (unquoted) used for stratification in the outer folds.
+#' @param inside_strata Optional variable name (unquoted) used for stratification within the inner validation splits.
+#' @param outside_breaks Optional number of quantile bins to discretize `outside_strata` if it is continuous.
+#' @param inside_breaks Optional number of quantile bins to discretize `inside_strata` if it is continuous.
+#' @param seed Optional integer for reproducibility.
+#'
+#' @return A tibble of class `nested_cv` with outer resampling splits and corresponding
+#'         inner validation resamples (as `v_splt` objects inside `inner_resamples` column).
+#'
+#' @importFrom rsample vfold_cv initial_validation_split validation_set
+#' @importFrom purrr map
+#' @noRd
+create_manual_nested_cv <- function(
+    data,
+    outside_folds = 5,
+    inside_prop = c(0.75, 0.25),
+    outside_strata = NULL,
+    inside_strata = NULL,
+    outside_breaks = NULL,
+    inside_breaks = NULL,
+    seed = NULL) {
+
+  if (!is.null(seed)) set.seed(seed)
+
+  # Automatically adjust inside_prop if sum == 1
+  if (length(inside_prop) == 2 && sum(inside_prop) >= 1) {
+  #  message_sf_1 <- c("Sum of inside_prop equals 1 — reducing second value slightly to avoid error.")
+  #  message(colourise(message_sf_1, "blue"))
+    inside_prop[2] <- inside_prop[2] - 1e-8
+  }
+
+  # Outer folds using vfold_cv()
+  outer_folds <- rsample::vfold_cv(
+    data,
+    v = outside_folds,
+    strata = outside_strata,
+    breaks = outside_breaks
+  )
+
+  # Manually assign inner validation resamples in the correct v_splt format
+  outer_folds$inner_resamples <- purrr::map(outer_folds$splits, function(split) {
+    training_data <- rsample::analysis(split)
+
+    three_way_split <- rsample::initial_validation_split(
+      training_data,
+      prop = inside_prop,
+      strata = inside_strata,
+      breaks = inside_breaks
+    )
+
+    rsample::validation_set(three_way_split)  # convert to expected v_splt format
+  })
+
+  outer_folds
+}
+
 
 #' Train word embeddings to a numeric variable.
 #'
@@ -1025,10 +1088,11 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
 #' @param multi_cores If TRUE it enables the use of multiple cores if the computer system allows for it
 #'  (i.e., only on unix, not windows). Hence it makes the analyses considerably faster to run. Default is
 #'  "multi_cores_sys_default", where it automatically uses TRUE for Mac and Linux and FALSE for Windows.
-#' @param save_output (character) Option not to save all output; default = "all". see also "only_results"
-#'  and "only_results_predictions".
-#' @param simulate.p.value (Boolean) From fisher.test: a logical indicating whether to compute p-values by
-#' Monte Carlo simulation, in larger than 2 * 2 tables.
+#' @param save_output (character) Option not to save all output; default = "all". see also "no_plot", "only_results",
+#'  and "only_results_predictions". Note that "no_plot" is good when wanting to save a logistic or multnomial regression,
+#'  since the lot makes the saved object bloated when being saved.
+#' @param simulate.p.value (Boolean or string) From fisher.test: a logical indicating whether to compute p-values by
+#' Monte Carlo simulation, in larger than 2 * 2 tables. The test can be turned off if set to "turn_off".
 #' @param seed (numeric) Set different seed (default = 2020).
 #' @param ... For example settings in yardstick::accuracy to set event_level (e.g., event_level = "second").
 #' @details
@@ -1064,7 +1128,7 @@ check_nested_cv_setup <- function(results_nested_resampling, id_variable = "id_n
 #' @importFrom stats cor.test na.omit lm
 #' @importFrom dplyr bind_cols select starts_with filter all_of add_row
 #' @importFrom recipes recipe step_naomit step_center step_scale step_pca all_predictors
-#' @importFrom rsample vfold_cv
+#' @importFrom rsample vfold_cv initial_validation_split
 #' @importFrom parsnip linear_reg set_engine multinom_reg
 #' @importFrom tune tune control_grid tune_grid select_best collect_predictions
 #' @importFrom magrittr %>%
@@ -1250,25 +1314,27 @@ textTrainRegression <- function(
         breaks = !!inside_breaks
       )
     ))
+    results_nested_resampling <- rlang::eval_tidy(results_nested_resampling)
   }
+
+
   if (cv_method == "validation_split") {
-    results_nested_resampling <- rlang::expr(rsample::nested_cv(
-      xy,
-      outside = rsample::vfold_cv(
-        v = !!outside_folds,
-        repeats = 1,
-        strata = !!outside_strata_y,
-        breaks = !!outside_breaks
-      ),
-      inside = rsample::validation_split(
-        prop = !!inside_folds,
-        strata = !!inside_strata_y,
-        breaks = !!inside_breaks
-      )
-    ))
+
+    # inside_prop requires two digits (but we want to keep so only one is requried)
+    inside_folds <- c(inside_folds, (1-inside_folds))
+
+    results_nested_resampling <- create_manual_nested_cv(
+      data = xy,
+      outside_folds = outside_folds,
+      inside_prop = inside_folds,
+      outside_strata = outside_strata_y,
+      inside_strata = inside_strata_y,
+      outside_breaks = outside_breaks,
+      inside_breaks = inside_breaks,
+      seed = seed
+    )
   }
 
-  results_nested_resampling <- rlang::eval_tidy(results_nested_resampling)
 
   # Deciding whether to use multicores depending on system and settings.
   if (multi_cores == "multi_cores_sys_default") {
@@ -1376,7 +1442,11 @@ textTrainRegression <- function(
 
     collected_results <- list(predy_y, collected_results)
   } else if (model == "logistic") {
-    collected_results <- classification_results(outputlist_results_outer = outputlist_results_outer, ...)
+    collected_results <- classification_results(
+      outputlist_results_outer = outputlist_results_outer,
+      simulate.p.value = simulate.p.value
+      , ...
+      )
 
     #  Save predictions outside list to make similar structure as model == regression output.
     predy_y <- collected_results$predy_y
@@ -1385,7 +1455,8 @@ textTrainRegression <- function(
   } else if (model == "multinomial") {
     collected_results <- classification_results_multi(
       outputlist_results_outer = outputlist_results_outer,
-      simulate.p.value = simulate.p.value, ...
+      simulate.p.value = simulate.p.value
+      , ...
     )
 
     #  Save predictions outside list to make similar structure as model == regression output.
@@ -1618,11 +1689,12 @@ textTrainRegression <- function(
     nr_predictors
   )
 
+
   # Removing parts of the model not needed for prediction (primarily removing training data)
   final_predictive_model$pre$mold$predictors <- NULL
   final_predictive_model$pre$mold$outcomes <- NULL
   final_predictive_model$pre$mold$extras <- NULL
-
+  # saveSize(final_predictive_model)
 
   ##### NEW ENVIRONMENT END
 
@@ -1758,6 +1830,8 @@ textTrainRegression <- function(
                                             aggregation = "max"
     ) %>% dplyr::bind_rows()
 
+
+
     aggregated_word_embeddings <- list(
       aggregated_word_embedding_mean = aggregated_word_embedding_mean,
       aggregated_word_embedding_min = aggregated_word_embedding_min,
@@ -1767,6 +1841,8 @@ textTrainRegression <- function(
     aggregated_word_embeddings = paste0("The aggregated word embeddings were not saved.")
   }
 
+  rm(all_we)
+
   if (model == "regression") {
     if (save_output == "all") {
       final_results <- list(
@@ -1824,6 +1900,17 @@ textTrainRegression <- function(
         "roc_curve_data", "roc_curve_plot", "fisher", "chisq", "results_metrics"
       )
       final_results
+    } else if (save_output == "no_plot") {
+      final_results <- list(
+        final_predictive_model, model_description_detail, collected_results$roc_curve_data, collected_results$fisher,
+        collected_results$chisq, collected_results$results_collected
+      )
+      names(final_results) <- c(
+        "final_model", "model_description", "roc_curve_data",  "fisher",
+        "chisq", "results_metrics"
+      )
+      final_results
+      # saveSize(final_results)
     }
     final_results
   } else if (model == "multinomial") {
@@ -1860,6 +1947,15 @@ textTrainRegression <- function(
         "roc_curve_data", "roc_curve_plot", "fisher", "chisq", "results_metrics"
       )
       final_results
+    } else if (save_output == "no_plot") {
+      final_results <- list(
+        final_predictive_model, model_description_detail, collected_results$roc_curve_data, collected_results$fisher,
+        collected_results$chisq, collected_results$results_collected
+      )
+      names(final_results) <- c(
+        "final_model", "model_description", "roc_curve_data",  "fisher", "chisq", "results_metrics"
+      )
+      final_results
     }
     final_results
   }
@@ -1871,6 +1967,7 @@ textTrainRegression <- function(
   remove(y)
   remove(x2)
   remove(xy)
+  remove(strata)
 
   remove(predy_y)
   remove(preprocessing_recipe_save)
